# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`selinux`](#selinux)
* [`selinux::config`](#selinux--config): Set global SELinux system parameters
* [`selinux::install`](#selinux--install): Install selinux-related packages not managed by vox_selinux
* [`selinux::service`](#selinux--service): Ensures mcstrans and restorecond services managed

### Resource types

* [`selinux_login`](#selinux_login): Manage SELinux login mapping configuration  NOTE: You may need to run `restorecon -RF` on any user home directories that have their default c
* [`selinux_state`](#selinux_state): Toggle the enforcement of selinux

### Data types

* [`Selinux::State`](#Selinux--State): Types of selinux enforcement

## Classes

### <a name="selinux"></a>`selinux`

The selinux class.

#### Parameters

The following parameters are available in the `selinux` class:

* [`package_ensure`](#-selinux--package_ensure)
* [`login_resources`](#-selinux--login_resources)
* [`manage_mcstrans_package`](#-selinux--manage_mcstrans_package)
* [`manage_mcstrans_service`](#-selinux--manage_mcstrans_service)
* [`mcstrans_package_name`](#-selinux--mcstrans_package_name)
* [`mcstrans_service_name`](#-selinux--mcstrans_service_name)
* [`manage_restorecond_package`](#-selinux--manage_restorecond_package)
* [`manage_restorecond_service`](#-selinux--manage_restorecond_service)
* [`restorecond_package_name`](#-selinux--restorecond_package_name)
* [`ensure`](#-selinux--ensure)
* [`kernel_enforce`](#-selinux--kernel_enforce)
* [`autorelabel`](#-selinux--autorelabel)
* [`manage_utils_package`](#-selinux--manage_utils_package)
* [`mode`](#-selinux--mode)

##### <a name="-selinux--package_ensure"></a>`package_ensure`

Data type: `String`

The ensure status of packages to be installed

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'present' })`

##### <a name="-selinux--login_resources"></a>`login_resources`

Data type: `Optional[Hash]`

A hash of resources that should be created on the system as expected by
`create_resources()` called on the `selinux_login` type

A deep merge strategy is used when performing APL lookups on this value by
default.

@example Change __default__ to user_u
  ---
  selinux::login_resources:
    "__default__":
      seuser: user_u
      mls_range: s0
    "%admins":
      seuser: staff_u
      # This only works if you enable mcstransd
      # using selinux::manage_mcstrans_service: true
      mls_range: "SystemLow-SystemHigh"

Default value: `undef`

##### <a name="-selinux--manage_mcstrans_package"></a>`manage_mcstrans_package`

Data type: `Boolean`



##### <a name="-selinux--manage_mcstrans_service"></a>`manage_mcstrans_service`

Data type: `Boolean`



##### <a name="-selinux--mcstrans_package_name"></a>`mcstrans_package_name`

Data type: `String`



##### <a name="-selinux--mcstrans_service_name"></a>`mcstrans_service_name`

Data type: `String`



##### <a name="-selinux--manage_restorecond_package"></a>`manage_restorecond_package`

Data type: `Boolean`



##### <a name="-selinux--manage_restorecond_service"></a>`manage_restorecond_service`

Data type: `Boolean`



##### <a name="-selinux--restorecond_package_name"></a>`restorecond_package_name`

Data type: `String`



##### <a name="-selinux--ensure"></a>`ensure`

Data type: `Selinux::State`



Default value: `'enforcing'`

##### <a name="-selinux--kernel_enforce"></a>`kernel_enforce`

Data type: `Boolean`



Default value: `false`

##### <a name="-selinux--autorelabel"></a>`autorelabel`

Data type: `Boolean`



Default value: `false`

##### <a name="-selinux--manage_utils_package"></a>`manage_utils_package`

Data type: `Boolean`



Default value: `true`

##### <a name="-selinux--mode"></a>`mode`

Data type: `Enum['targeted','mls']`



Default value: `'targeted'`

### <a name="selinux--config"></a>`selinux::config`

Set global SELinux system parameters

### <a name="selinux--install"></a>`selinux::install`

Install selinux-related packages not managed by vox_selinux

#### Parameters

The following parameters are available in the `selinux::install` class:

* [`manage_utils_package`](#-selinux--install--manage_utils_package)
* [`utils_packages`](#-selinux--install--utils_packages)
* [`manage_mcstrans_package`](#-selinux--install--manage_mcstrans_package)
* [`mcstrans_package_name`](#-selinux--install--mcstrans_package_name)
* [`manage_restorecond_package`](#-selinux--install--manage_restorecond_package)
* [`restorecond_package_name`](#-selinux--install--restorecond_package_name)
* [`package_ensure`](#-selinux--install--package_ensure)

##### <a name="-selinux--install--manage_utils_package"></a>`manage_utils_package`

Data type: `Boolean`



Default value: `pick(getvar('selinux::manage_utils_package'), true)`

##### <a name="-selinux--install--utils_packages"></a>`utils_packages`

Data type: `Array[String]`



Default value: `['checkpolicy']`

##### <a name="-selinux--install--manage_mcstrans_package"></a>`manage_mcstrans_package`

Data type: `Boolean`



Default value: `simplib::lookup('selinux::manage_mcstrans_package')`

##### <a name="-selinux--install--mcstrans_package_name"></a>`mcstrans_package_name`

Data type: `String`



Default value: `simplib::lookup('selinux::mcstrans_package_name')`

##### <a name="-selinux--install--manage_restorecond_package"></a>`manage_restorecond_package`

Data type: `Boolean`



Default value: `simplib::lookup('selinux::manage_restorecond_package')`

##### <a name="-selinux--install--restorecond_package_name"></a>`restorecond_package_name`

Data type: `String`



Default value: `simplib::lookup('selinux::restorecond_package_name')`

##### <a name="-selinux--install--package_ensure"></a>`package_ensure`

Data type: `String`



Default value: `simplib::lookup('selinux::package_ensure', { 'default_value' => simplib::lookup('simp_options::package_ensure', { 'default_value' => 'present' } ) } )`

### <a name="selinux--service"></a>`selinux::service`

Ensures mcstrans and restorecond services managed

## Resource types

### <a name="selinux_login"></a>`selinux_login`

Manage SELinux login mapping configuration

NOTE: You may need to run `restorecon -RF` on any user home directories that
have their default contexts updated. This is particularly important for the
`__default__` login entry but cannot be automated given the potential load
and unintended system consequences.

#### Properties

The following properties are available in the `selinux_login` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `mls_range`

Valid values: `/^.+$/`

The Multi-Level Security range to be applied to the login

##### `seuser`

Valid values: `/^.+$/`

The SELinux user to which the login should be mapped.
You can get a list by running `semanage user -l`

#### Parameters

The following parameters are available in the `selinux_login` type.

* [`force`](#-selinux_login--force)
* [`name`](#-selinux_login--name)
* [`provider`](#-selinux_login--provider)

##### <a name="-selinux_login--force"></a>`force`

Valid values: `true`, `false`, `yes`, `no`

Force the modification of potentially unsafe logins such as "root" and "__default__"

Default value: `false`

##### <a name="-selinux_login--name"></a>`name`

namevar

The user or group name to be managed. Groups must be prefixed with a "%"

##### <a name="-selinux_login--provider"></a>`provider`

The specific backend to use for this `selinux_login` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="selinux_state"></a>`selinux_state`

Toggle the enforcement of selinux

#### Properties

The following properties are available in the `selinux_state` type.

##### `ensure`

Valid values: `false`, `true`, `disabled`, `permissive`, `enforcing`

Set the SELinux state on the system

Default value: `enforcing`

#### Parameters

The following parameters are available in the `selinux_state` type.

* [`autorelabel`](#-selinux_state--autorelabel)
* [`name`](#-selinux_state--name)
* [`provider`](#-selinux_state--provider)

##### <a name="-selinux_state--autorelabel"></a>`autorelabel`

Valid values: `true`, `false`, `yes`, `no`

Automatically determine if the filesystem needs to be relabeled.
  Enforcing > Permissive > Disabled
Going to the right requires relabeling.

Default value: `true`

##### <a name="-selinux_state--name"></a>`name`

namevar

An arbitrary, but unique, name for the resource.

##### <a name="-selinux_state--provider"></a>`provider`

The specific backend to use for this `selinux_state` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

## Data types

### <a name="Selinux--State"></a>`Selinux::State`

Types of selinux enforcement

Alias of

```puppet
Variant[Boolean, Enum[
    'enforcing',
    'permissive',
    'disabled'
  ]]
```

